"use client";
import React, { useRef, useCallback, useEffect, useState } from "react";
const Dropdown = ({ items, ariaLabel, buttonLabel, buttonClassName, disabled, tickSelected, defaultSelectedLabel }) => {
    const dropdownRef = useRef(null);
    const dropdownContainerRef = useRef(null);
    const [selectedIndex, setSelectedIndex] = useState(-1);
    const activateDropdown = () => {
        if (dropdownRef.current) {
            dropdownRef.current.classList.toggle("show");
        }
    };
    const hideDropdown = () => {
        if (dropdownRef.current) {
            dropdownRef.current.classList.remove("show");
        }
    };
    const handleClickOutside = useCallback((event) => {
        if (dropdownContainerRef.current &&
            !dropdownContainerRef.current.contains(event.target)) {
            hideDropdown();
        }
    }, []);
    useEffect(() => {
        document.addEventListener("mousedown", handleClickOutside);
        return () => {
            document.removeEventListener("mousedown", handleClickOutside);
        };
    }, [handleClickOutside]);
    return (React.createElement("div", { className: "dropdown", ref: dropdownContainerRef },
        React.createElement("button", { onClick: activateDropdown, className: `dropdown-button ${buttonClassName}`, "aria-label": ariaLabel, disabled: disabled },
            React.createElement("span", null, buttonLabel)),
        React.createElement("div", { ref: dropdownRef, className: "dropdown-content", tabIndex: -1 },
            React.createElement("div", { className: "dropdown-items" }, items.map(({ label, onClick }, i) => (React.createElement("div", { key: i, className: "dropdown-item", onClick: () => {
                    if (onClick) {
                        onClick();
                        hideDropdown();
                        setSelectedIndex(i);
                    }
                }, "aria-label": typeof label === "string" ? label : undefined, role: "menuitem" },
                label,
                tickSelected && (selectedIndex === i || typeof label === "string" && defaultSelectedLabel === label) &&
                    React.createElement("span", { className: "select-item-icon-check" },
                        React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", fill: "none", stroke: "currentColor", strokeWidth: "2", strokeLinecap: "round", strokeLinejoin: "round" },
                            React.createElement("path", { d: "M20 6 9 17l-5-5" }))))))))));
};
export default Dropdown;
