"use client";
import React, { useRef, useCallback, useEffect, useState, } from "react";
const Select = ({ items, value, ariaLabel, onClick, defaultLabel, }) => {
    const selectRef = useRef(null);
    const selectContainerRef = useRef(null);
    const [label, setLabel] = useState(defaultLabel || "");
    const [selectedValue, setSelectedValue] = useState(value);
    const openSelect = () => {
        if (selectRef.current) {
            selectRef.current.classList.toggle("show");
        }
    };
    const closeSelect = () => {
        if (selectRef.current) {
            selectRef.current.classList.remove("show");
        }
    };
    const handleClickOutside = useCallback((event) => {
        if (selectContainerRef.current &&
            !selectContainerRef.current.contains(event.target)) {
            closeSelect();
        }
    }, []);
    useEffect(() => {
        document.addEventListener("mousedown", handleClickOutside);
        return () => {
            document.removeEventListener("mousedown", handleClickOutside);
        };
    }, [handleClickOutside]);
    const handleClick = (value, label) => {
        if (onClick)
            onClick(value);
        setSelectedValue(value);
        setLabel(label);
        closeSelect();
    };
    return (React.createElement("div", { className: "dropdown", ref: selectContainerRef },
        React.createElement("button", { onClick: openSelect, className: "dropdown-button accent-color-hover", "aria-label": ariaLabel },
            React.createElement("span", null, label || "Select an option")),
        React.createElement("div", { ref: selectRef, className: "select-content", tabIndex: -1 },
            React.createElement("div", { className: "dropdown-items" }, items.map(({ label, value }) => (React.createElement("div", { key: value, className: `dropdown-item
                 ${selectedValue === value ? "selected" : ""}`, onClick: () => handleClick(value, label), "aria-label": typeof label === "string" ? label : value.toString() },
                label,
                selectedValue === value && (React.createElement("span", { className: "select-item-icon-check" },
                    React.createElement("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", fill: "none", stroke: "currentColor", strokeWidth: "2", strokeLinecap: "round", strokeLinejoin: "round" },
                        React.createElement("path", { d: "M20 6 9 17l-5-5" })))))))))));
};
export default Select;
